"""
Settings
"""
API_VERSION       = 'v1'
API_HOST          = 'pili.qiniuapi.com'
AUTH              = None
RTMP_PUBLISH_HOST = None
RTMP_PLAY_HOST    = None
HLS_PLAY_HOST     = None
HUB               = None
