from setuptools import setup, find_packages

setup(
    name = 'pili',
    version = '0.0.6',
    keywords = ('pili'),
    description = 'SDK for pili',
    license = 'MIT License',
    install_requires = [],

    author = 'fanchenlin',
    author_email = 'fanchenlin@qiniu.com',

    packages = find_packages(),
    platforms = 'any',
)
